@@ -17,14 +17,14 @@ def upload_image(item: CommonsItem, site: pywikibot.Site, update_existing: bool
     imagepage.text = item.description
     try:
         if imagepage.exists():
-            logging.error("File {} exists on {}".format(
-                item.path.name, str(site)))
             if update_existing:
                 logging.info(f"Updating description of {item.path.name}")
                 if not dry_run:
                     imagepage.save("update")
                 return True
             else:
+                logging.info("File {} exists on {}, updating".format(
+                    item.path.name, str(site)))
                 return False
         else:
             if dry_run:
@@ -38,9 +38,9 @@ def upload_image(item: CommonsItem, site: pywikibot.Site, update_existing: bool
 
 
 def upload_pattypan_excel(filename: Path, update_existing: bool = False, max_uploads: int = -1,
-                          use_test_commons: bool = True, dry_run: bool = False):
+                          use_test_commons: bool = True, dry_run: bool = False, allow_missing_files: bool = False):
     try:
-        items = read_pattypan_input(filename)
+        items = read_pattypan_input(filename, allow_missing_files=allow_missing_files)
     except Exception as e:
         logging.error(e)
         return
